document: Solarized Syntax Highlighting in Microsoft Word

View source: R/solarizeddocx-package.R

documentR Documentation

Solarized Syntax Highlighting in Microsoft Word

Description

Solarized Syntax Highlighting in Microsoft Word

Usage

document(
  ...,
  reference_docx = "solarized",
  highlight = "solarized",
  syntax_definition = "solarized",
  pandoc_args = character(0)
)

Arguments

...

Arguments passed to rmarkdown::word_document().

reference_docx

Reference docx file to use. By default, this value is set to use "solarized" to use this package's file. Alternatively, one could "default" for pandoc's default file or a path to a custom docx file.

highlight

Syntax highlighting style to use. By default, this value is set to "solarized" to use this package's syntax definition. See alternatives in rmarkdown::word_document().

syntax_definition

Syntax definition to use for syntax highlighting. Defaults to "solarized" to use this package's language definition. This option is not one available to rmarkdown::word_document(), but setting this argument to NULL or "default" will use the default behavior.

pandoc_args

Additional command line options to pass to pandoc. (This should be a character vector of options.)

Value

An RMarkdown output format for Word documents.

Examples

## Not run: 
rmarkdown::render("test.Rmd", output_format = solarizeddocx::document())

## End(Not run)

tjmahr/solarizeddocx documentation built on May 4, 2022, 3:35 p.m.